- image
3-layer RGB/4-layer RGBA array, rayimg class, or filename of an image.
- convert_to_array
Default FALSE. Whether to convert 2D B&W images/matrices to RGBA arrays.
- preview
Default FALSE. If TRUE, it will display the image in addition
to returning it.
- source_linear
Default NA, automatically determined based on the image type.
Whether the image source is linear data or sRGB. TRUE for matrices, arrays, and
floating-point HDR formats (EXR, HDR), and DNG; FALSE for all other file-based formats
(e.g., jpeg, png, tiff, tga, bmp, psd, gif, pic, pnm).
- normalize
Default FALSE. If TRUE, convert to normalize_to space on read. Note that
rayimg inputs will keep their colorspace and ignore this option--use render_convert_colorspace()
to change an existing rayimg to a new colorspace.
- dng_normalize
Default FALSE. If TRUE, DNG data is normalized to 0..1,
using black/white levels; if FALSE, raw values are returned.
- normalize_to
Default CS_ACESCG. Target colorspace when normalize=TRUE.
- normalize_adapt_white
Default TRUE. If TRUE, Bradford-adapt source white to target white.
- assume_colorspace
Default NULL. A colorspace descriptor (e.g., CS_SRGB,
CS_ACESCG). If given, the loaded image will be tagged with this space
rather than the default inferred by file type. No pixel conversion is performed
unless normalize=TRUE.
- assume_white
Default NULL. Scene/display white for the loaded image.
Either a named white ("D60","D65","D50","D55","D75","E") or XYZ with Y=1.
If NULL, uses assume_colorspace$white_xyz.
- reset_camera_settings
Default FALSE. If TRUE, reset informational
exposure/ISO metadata to neutral values (exposure = 0, iso = 100) when
wrapping an existing rayimg or attributed array.
- ...
Arguments to pass to jpeg::readJPEG, png::readPNG, tiff::readTIFF,
or libopenexr::read_exr() for supported formats.