ray_write_image: Write Image

View source: R/ray_write_image.R

ray_write_imageR Documentation

Write Image

Description

Takes an RGB array/filename and writes it to file.

Usage

ray_write_image(image, filename, clamp = FALSE, write_linear = NA, ...)

Arguments

image

3-layer RGB/4-layer RGBA array, rayimg class, or filename of an image.

filename

File to write to, with filetype determined by extension. Filetype can be PNG, JPEG, TIFF, EXR, or DNG.

clamp

Default FALSE, automatically determined. Whether to clamp the image to 0-1. If the file extension is PNG of JPEG, this is forced to TRUE.

write_linear

Default NA, automatically determined. By default, images will be gamma corrected (write_linear = FALSE) for all file types except EXR and DNG (which are linear formats), unless otherwise specified.

...

Arguments to pass to either jpeg::writeJPEG, png::writePNG, libopenexr::write_exr, or tiff::writeTIFF.

Value

A rayimg RGBA array.

Examples


#Write as a png
tmparr = tempfile(fileext=".png")
ray_read_image(dragon) |>
 ray_write_image(tmparr)
ray_read_image(tmparr) |>
 plot_image()
#Write as a JPEG (passing quality arguments via ...)
tmparr = tempfile(fileext=".jpg")
ray_read_image(dragon) |>
 ray_write_image(tmparr, quality = 0.2)
ray_read_image(tmparr) |>
 plot_image()
#Write as a tiff
tmparr = tempfile(fileext=".tiff")
ray_read_image(dragon) |>
 ray_write_image(tmparr)
ray_read_image(tmparr) |>
  plot_image()


rayimage documentation built on June 12, 2026, 5:06 p.m.