View source: R/render_white_balance.R
| render_white_balance | R Documentation |
Chromatic-adapt an image from reference_white to target_white in its working RGB space.
When bake = FALSE (the default), this should not result in any visible changes to the image when
plotted in rayimage via plot_image(), as that function then corrects the white balance for
display. Set
render_white_balance(
image,
reference_white = NA,
target_white = "D60",
bake = FALSE,
filename = NULL,
preview = FALSE
)
image |
Default |
reference_white |
Default |
target_white |
Default |
bake |
Default |
filename |
Default |
preview |
Default |
# Not specifying a target white balance returns an unchanged image
render_white_balance(dragon, preview = TRUE)
# Default white "D60", converting to D50 produces a warmer image
render_white_balance(dragon, preview = TRUE, target_white = "D50", bake = TRUE)
# Default white "D60", converting to "D75" produces a cooler image
render_white_balance(dragon, preview = TRUE, target_white = "D75", bake = TRUE)
# Set reference white to colder "D75", converting to "D50" produces a very warm image
render_white_balance(dragon, preview = TRUE,
reference_white= "D75", target_white = "D50", bake = TRUE)
# With a real, non-rendered image:
render_white_balance(sunset_image, preview=TRUE)
# Cooler
render_white_balance(sunset_image, preview=TRUE, target_white = "D75", bake = TRUE)
# Warmer
render_white_balance(sunset_image, preview=TRUE, target_white = "D50", bake = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.