View source: R/convert_color.R
| convert_color | R Documentation |
Convert Color
convert_color(color, as_hex = FALSE, single = FALSE)
color |
The color to convert. Can be either an R color string, or a
numeric scalar, RGB vector, RGBA vector, or RGB/RGBA matrix with values
between |
as_hex |
Default |
single |
Default |
RGB or RGBA color vector, or a color matrix for multiple colors.
#none
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.