Learn R Programming

rayimage (version 0.26.1)

convert_to_native_raster: Convert to Native Raster

Description

Converts a matrix or image array to a native raster.

Usage

convert_to_native_raster(input)

Arguments

input

Matrix or image array to convert to a native raster.