Learn R Programming

rayimage (version 0.26.1)

interpolate_array: Matrix/Array Interpolation

Description

Given a series of X and Y coordinates and an array/matrix, interpolates the Z coordinate using bilinear interpolation.

Usage

interpolate_array(image, x, y)

Value

Either a vector of values (if image is a matrix) or a list of interpolated values from each layer.

Arguments

image

3-layer RGB/4-layer RGBA array, rayimg class, or filename of an image.

x

X indices (or fractional index) to interpolate.

y

Y indices (or fractional index) to interpolate.

Examples

Run this code
#if(interactive()){
#Interpolate a matrix
interpolate_array(volcano,c(10,10.1,11),c(30,30.5,33))
#Interpolate a 3-layer array (returns list for each channel)
interpolate_array(dragon,c(10,10.1,11),c(30,30.5,33))
#end}

Run the code above in your browser using DataLab